// Template for SDCC 8051 C Language

#include <at89x51.h> // Definitions of registers, SFRs and Bits

void uart_init(void)	// Set UART Baud Rate to 9600 bps
{
__asm
	anl	PCON,#0x7F	// Clear SMOD of PCON, No Double Baud Rate
	anl	TMOD,#0xAF	// Clear C/T, M0 for Timer1 of TMOD
	orl	TMOD,#0x20	// Set M1 for Timer1 of TMOD
				// Set Timer1 to Mode 2 (8-bit auto reload) for Baud Rate Generation
	mov	TH1,#0xFD	// Set Baud Rate to 9600 bps
	clr	SM0		// Clear SM0 of SCON
	setb	SM1		// Set SM1 of SCON
				// Set UART to Mode 1 (8-bit UART)
	setb	REN		// Set REN of SCON to Enable UART Receive
	setb	TR1		// Set TR1 of TCON to Start Timer1
	clr	TI		// Clear TI of SCON to Get Ready to Send
	clr	RI		// Clear RI of SCON to Get Ready to Receive
__endasm;
}

void putchar(char c)
{
SBUF=c;
while(TI==0);
TI=0;
}

// ISR Prototypes ===================================================
void INT0_ISR(void)	__interrupt 0; // ISR for External Interrupt 0
void T0_ISR(void)	__interrupt 1; // ISR for Timer0/Counter0 Overflow
void INT1_ISR(void)	__interrupt 2; // ISR for External Interrupt 1
void T1_ISR(void)	__interrupt 3; // ISR for Timer1/Counter1 Overflow
void UART_ISR(void)	__interrupt 4; // ISR for UART Interrupt

__xdata __at 0x6000 char x[8192];

void main(void)
{
char c;
int i;

c='A';
for(i=0;i<8192;i++)
	{
	x[i]=c;
	c++;
	if(c>'Z')
		c='A';
	}

uart_init();

for(i=0;i<8192;i++)
	putchar(x[i]);

while(1);
}

void INT0_ISR(void)	__interrupt 0
{}
void T0_ISR(void)	__interrupt 1
{}
void INT1_ISR(void)	__interrupt 2
{}
void T1_ISR(void)	__interrupt 3
{}
void UART_ISR(void)	__interrupt 4
{}

